Struct websocket_client::Socket[][src]

pub struct Socket { /* fields omitted */ }

Methods

impl Socket
[src]

Creates a new Socket.

Sends a textual message.

Sends a binary message.

Returns all messages that have been received since the last call to this function.

Returns None if there's be an error or the Socket has been disconnected, and Some(vec![]) if no messages have been received. If this returns None, this Socket should no longer be used.